# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_VOLMASK_METADATA = Metadata(
    id="ff800b0130320a3ca061f0dce6a9fb1136b538ad.boutiques",
    name="mris_volmask",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisVolmaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_volmask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_volmask(
    io_: str,
    cap_distance: float | None = None,
    label_background: float | None = None,
    label_left_white: float | None = None,
    label_left_ribbon: float | None = None,
    label_right_white: float | None = None,
    label_right_ribbon: float | None = None,
    surf_white: str | None = None,
    surf_pial: str | None = None,
    aseg_name: str | None = None,
    out_root: str | None = None,
    subjects_dir: str | None = None,
    save_distance: bool = False,
    lh_only: bool = False,
    rh_only: bool = False,
    parallel: bool = False,
    edit_aseg: bool = False,
    save_ribbon: bool = False,
    runner: Runner | None = None,
) -> MrisVolmaskOutputs:
    """
    Computes a volume mask, at the same resolution as the <subject>/mri/brain.mgz.
    The volume mask contains 4 values: LH_WM (default 10), LH_GM (default 100),
    RH_WM (default 20), RH_GM (default 200).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        io_: Positional argument that represents input/output settings.
        cap_distance: Maximum distance up to which the signed distance function\
            computation is accurate.
        label_background: Override default value for background label value\
            (0).
        label_left_white: Override default value for left white matter label\
            (20).
        label_left_ribbon: Override default value for left ribbon label (10).
        label_right_white: Override default value for right white matter label\
            (120).
        label_right_ribbon: Override default value for right ribbon label\
            (110).
        surf_white: Surface root name (e.g. <subject>/surf/$hemi.<NAME> -\
            default value is white).
        surf_pial: Surface root name (e.g. <subject>/surf/$hemi.<NAME> -\
            default value is pial).
        aseg_name: Specify a different name for the aseg input file (default is\
            aseg).
        out_root: Output root name (default is ribbon). Output files would be,\
            for example, mri/ribbon.mgz.
        subjects_dir: Specify SUBJECTS_DIR, default is read from environment.
        save_distance: Save the signed distance function as ?h.dwhite.mgz and\
            ?h.dpial.mgz.
        lh_only: Only process left hemisphere.
        rh_only: Only process right hemisphere.
        parallel: Run hemispheres in parallel and combine the result.
        edit_aseg: Edit the aseg using the ribbons and save to aseg.ribbon.mgz.
        save_ribbon: Save just the ribbon for the hemispheres - in the format\
            ?h.ribbon.mgz.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisVolmaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_VOLMASK_METADATA)
    cargs = []
    cargs.append("mris_volmask")
    if cap_distance is not None:
        cargs.extend([
            "--cap_distance",
            str(cap_distance)
        ])
    if label_background is not None:
        cargs.extend([
            "--label_background",
            str(label_background)
        ])
    if label_left_white is not None:
        cargs.extend([
            "--label_left_white",
            str(label_left_white)
        ])
    if label_left_ribbon is not None:
        cargs.extend([
            "--label_left_ribbon",
            str(label_left_ribbon)
        ])
    if label_right_white is not None:
        cargs.extend([
            "--label_right_white",
            str(label_right_white)
        ])
    if label_right_ribbon is not None:
        cargs.extend([
            "--label_right_ribbon",
            str(label_right_ribbon)
        ])
    if surf_white is not None:
        cargs.extend([
            "--surf_white",
            surf_white
        ])
    if surf_pial is not None:
        cargs.extend([
            "--surf_pial",
            surf_pial
        ])
    if aseg_name is not None:
        cargs.extend([
            "--aseg_name",
            aseg_name
        ])
    if out_root is not None:
        cargs.extend([
            "--out_root",
            out_root
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if save_distance:
        cargs.append("--save_distance")
    if lh_only:
        cargs.append("--lh-only")
    if rh_only:
        cargs.append("--rh-only")
    if parallel:
        cargs.append("--parallel")
    if edit_aseg:
        cargs.append("--edit_aseg")
    if save_ribbon:
        cargs.append("--save_ribbon")
    cargs.append(io_)
    ret = MrisVolmaskOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_VOLMASK_METADATA",
    "MrisVolmaskOutputs",
    "mris_volmask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VENTFIX_METADATA = Metadata(
    id="6168063cf3610f25b84854e501fcd4f1bf642f43.boutiques",
    name="ventfix",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class VentfixOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ventfix(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fixed_ventricles: OutputPathType
    """Output image with fixed ventricles"""


def ventfix(
    subject_dir: str,
    option1: str | None = None,
    runner: Runner | None = None,
) -> VentfixOutputs:
    """
    Tool for fixing ventricles in MRI scans.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Path to the subject's directory containing MRI scans.
        option1: Description of option 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VentfixOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VENTFIX_METADATA)
    cargs = []
    cargs.append("ventfix")
    cargs.append(subject_dir)
    if option1 is not None:
        cargs.extend([
            "--option1",
            option1
        ])
    ret = VentfixOutputs(
        root=execution.output_file("."),
        fixed_ventricles=execution.output_file(subject_dir + "/fixed_ventricles.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VENTFIX_METADATA",
    "VentfixOutputs",
    "ventfix",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DEBLANK_FILE_NAMES_METADATA = Metadata(
    id="da8da0abd18b50263679955b0ea74ae940b81571.boutiques",
    name="@DeblankFileNames",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDeblankFileNamesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__deblank_file_names(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__deblank_file_names(
    move: bool = False,
    nobrac: bool = False,
    demo_set: bool = False,
    echo: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> VDeblankFileNamesOutputs:
    """
    A script to remove blanks and other annoying characters ([], ()) from filenames.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        move: Actually rename the files (opposite of -dry_run).
        nobrac: Do not replace () and [] in filenames, just spaces.
        demo_set: Create a toy directory with bad names for testing.
        echo: Turn on script echo.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDeblankFileNamesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DEBLANK_FILE_NAMES_METADATA)
    cargs = []
    cargs.append("@DeblankFileNames")
    if move:
        cargs.append("-move")
    if nobrac:
        cargs.append("-nobrac")
    if demo_set:
        cargs.append("-demo_set")
    if echo:
        cargs.append("-echo")
    if help_:
        cargs.append("-help")
    cargs.append("[FILES...]")
    ret = VDeblankFileNamesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDeblankFileNamesOutputs",
    "V__DEBLANK_FILE_NAMES_METADATA",
    "v__deblank_file_names",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__TIME_DIFF_METADATA = Metadata(
    id="7889ba0aeecc01a9a55b923b84e149e7cec9417e.boutiques",
    name="@TimeDiff",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VTimeDiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__time_diff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__time_diff(
    file1: InputPathType,
    file2: InputPathType,
    runner: Runner | None = None,
) -> VTimeDiffOutputs:
    """
    A tool to compare the modification times of two files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        file1: First file to compare (e.g., file1.txt).
        file2: Second file to compare (e.g., file2.txt).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VTimeDiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__TIME_DIFF_METADATA)
    cargs = []
    cargs.append("@TimeDiff")
    cargs.append(execution.input_file(file1))
    cargs.append(execution.input_file(file2))
    ret = VTimeDiffOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VTimeDiffOutputs",
    "V__TIME_DIFF_METADATA",
    "v__time_diff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__2DWARPER_METADATA = Metadata(
    id="00a0f14e7b2cc538eab7a1270968f6ba94c6c2e3.boutiques",
    name="@2dwarper",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V2dwarperOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__2dwarper(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Warped output image from the dataset"""


def v__2dwarper(
    input_dataset: InputPathType,
    runner: Runner | None = None,
) -> V2dwarperOutputs:
    """
    2D image warping tool.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input dataset (e.g., image to be warped).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V2dwarperOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__2DWARPER_METADATA)
    cargs = []
    cargs.append("@2dwarper")
    cargs.append(execution.input_file(input_dataset))
    ret = V2dwarperOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("warped_output"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V2dwarperOutputs",
    "V__2DWARPER_METADATA",
    "v__2dwarper",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AFNI_RUN_ME_METADATA = Metadata(
    id="aeac26149fa34d0c42e1c07c261b19ac0706d90b.boutiques",
    name="@afni.run.me",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAfniRunMeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__afni_run_me(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__afni_run_me(
    go: bool = False,
    curl: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> VAfniRunMeOutputs:
    """
    A tool to execute a specific command.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        go: Execute the work.
        curl: Default to curl instead of wget.
        help_: Show help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAfniRunMeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AFNI_RUN_ME_METADATA)
    cargs = []
    cargs.append("@afni.run.me")
    if go:
        cargs.append("-go")
    if curl:
        cargs.append("-curl")
    if help_:
        cargs.append("-help")
    ret = VAfniRunMeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAfniRunMeOutputs",
    "V__AFNI_RUN_ME_METADATA",
    "v__afni_run_me",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_ONLY_SUBJECT_RH_METADATA = Metadata(
    id="cf178313d144b58ca109c79e9c3499855a731ab6.boutiques",
    name="morph_only_subject-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphOnlySubjectRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_only_subject_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """The output morphing files for the right hemisphere generated by the
    process."""


def morph_only_subject_rh(
    subject_dir: InputPathType,
    runner: Runner | None = None,
) -> MorphOnlySubjectRhOutputs:
    """
    This tool processes morph-specific operations for the right hemisphere of the
    brain using Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Path to the subject's directory containing the necessary\
            input files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphOnlySubjectRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_ONLY_SUBJECT_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "morph_only_subject" + execution.input_file(subject_dir)
    ])
    ret = MorphOnlySubjectRhOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file("/usr/local/freesurfer/subjects/" + pathlib.Path(subject_dir).name + "/rh.morph"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_ONLY_SUBJECT_RH_METADATA",
    "MorphOnlySubjectRhOutputs",
    "morph_only_subject_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_CALC_MONT_DIMS_PY_METADATA = Metadata(
    id="4d9e1251726a46e6f7e2c846f8a4c9e80c3f25b6.boutiques",
    name="adjunct_calc_mont_dims.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctCalcMontDimsPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_calc_mont_dims_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def adjunct_calc_mont_dims_py(
    help_: bool = False,
    runner: Runner | None = None,
) -> AdjunctCalcMontDimsPyOutputs:
    """
    A helper function for the fat_proc* scripts.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        help_: Display help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctCalcMontDimsPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_CALC_MONT_DIMS_PY_METADATA)
    cargs = []
    cargs.append("adjunct_calc_mont_dims.py")
    if help_:
        cargs.append("-help")
    ret = AdjunctCalcMontDimsPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_CALC_MONT_DIMS_PY_METADATA",
    "AdjunctCalcMontDimsPyOutputs",
    "adjunct_calc_mont_dims_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_INIT_GLOBAL_TRACTOGRAPHY_METADATA = Metadata(
    id="67eb4585ff3c986788ed4212a3618bb647f3bf08.boutiques",
    name="mris_init_global_tractography",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisInitGlobalTractographyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_init_global_tractography(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_init_global_tractography(
    subject: str,
    parcellation: str,
    output_volume: str,
    runner: Runner | None = None,
) -> MrisInitGlobalTractographyOutputs:
    """
    Initializes global tractography for a given subject and parcellation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: The subject on which to perform tractography.
        parcellation: The parcellation to use for tractography.
        output_volume: Output volume of the initialized global tractography.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisInitGlobalTractographyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_INIT_GLOBAL_TRACTOGRAPHY_METADATA)
    cargs = []
    cargs.append("mris_init_global_tractography")
    cargs.append(subject)
    cargs.append(parcellation)
    cargs.append(output_volume)
    ret = MrisInitGlobalTractographyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_INIT_GLOBAL_TRACTOGRAPHY_METADATA",
    "MrisInitGlobalTractographyOutputs",
    "mris_init_global_tractography",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CURVATURE_STATS_METADATA = Metadata(
    id="471b147c9e4a5986d26ffc5619a8d1ade9f883a3.boutiques",
    name="mris_curvature_stats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCurvatureStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_curvature_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    scaled_curvature_file: OutputPathType
    """Scaled curvature file."""


def mris_curvature_stats(
    subject_name: str,
    hemisphere: str,
    runner: Runner | None = None,
) -> MrisCurvatureStatsOutputs:
    """
    Tool for calculating statistics on surface curvature values.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Subject name defined in the SUBJECTS_DIR.
        hemisphere: Hemisphere, can be 'lh' or 'rh'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCurvatureStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CURVATURE_STATS_METADATA)
    cargs = []
    cargs.append("mris_curvature_stats")
    cargs.append("[OPTIONS]")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    cargs.append("[CURVFILE...]")
    ret = MrisCurvatureStatsOutputs(
        root=execution.output_file("."),
        scaled_curvature_file=execution.output_file(subject_name + "/surf/" + hemisphere + ".[CURVATURE_FILES].scaled.crv"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CURVATURE_STATS_METADATA",
    "MrisCurvatureStatsOutputs",
    "mris_curvature_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GET_AFNI_MODEL_PRF_6_BAD_METADATA = Metadata(
    id="f7614b8ced72773ab9bfd46ff569ff9a092b84e3.boutiques",
    name="get_afni_model_PRF_6_BAD",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GetAfniModelPrf6BadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `get_afni_model_prf_6_bad(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def get_afni_model_prf_6_bad(
    amplitude: float,
    x_coord: float,
    y_coord: float,
    sigma: float,
    sigrat: float,
    theta: float,
    runner: Runner | None = None,
) -> GetAfniModelPrf6BadOutputs:
    """
    Command line tool for obtaining AFNI pRF model.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        amplitude: Amplitude parameter A.
        x_coord: X coordinate parameter x.
        y_coord: Y coordinate parameter y.
        sigma: Sigma parameter sigma.
        sigrat: Sigma ratio parameter sigrat.
        theta: Theta parameter theta (in radians).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GetAfniModelPrf6BadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GET_AFNI_MODEL_PRF_6_BAD_METADATA)
    cargs = []
    cargs.append("get_afni_model_PRF_6_BAD")
    cargs.append(str(amplitude))
    cargs.append(str(x_coord))
    cargs.append(str(y_coord))
    cargs.append(str(sigma))
    cargs.append(str(sigrat))
    cargs.append(str(theta))
    ret = GetAfniModelPrf6BadOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GET_AFNI_MODEL_PRF_6_BAD_METADATA",
    "GetAfniModelPrf6BadOutputs",
    "get_afni_model_prf_6_bad",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_MVLM_METADATA = Metadata(
    id="154c52f3fe6b8e8a5efedcc4503099b570dc9d4b.boutiques",
    name="fsl_mvlm",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslMvlmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_mvlm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Processed output file"""
    outdata: OutputPathType | None
    """Pre-processed data output file"""
    vnscales: OutputPathType | None
    """Variance normalisation scales file"""


def fsl_mvlm(
    input_file: InputPathType,
    basename_output_files: str,
    algorithm: str | None = None,
    design_matrix: InputPathType | None = None,
    mask_image: InputPathType | None = None,
    design_normalization: bool = False,
    variance_normalisation: bool = False,
    demean: bool = False,
    nmf_dim: float | None = None,
    nmf_iterations: float | None = None,
    verbose: bool = False,
    out_data: InputPathType | None = None,
    out_vnscales: InputPathType | None = None,
    runner: Runner | None = None,
) -> FslMvlmOutputs:
    """
    Multivariate Linear Model regression on time courses and/or 3D/4D images using
    SVD (PCA), PLS, normalised PLS, CVA, SVD-CVA or MLM.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Input file (text matrix or 3D/4D image file).
        basename_output_files: Basename for output files.
        algorithm: Algorithm for decomposition: PCA (or SVD; default), PLS,\
            orthoPLS, CVA, SVD-CVA, MLM, NMF.
        design_matrix: File name of the GLM design matrix (time courses or\
            spatial maps).
        mask_image: Mask image file name if input is an image.
        design_normalization: Switch on normalisation of the design matrix\
            columns to unit standard deviation.
        variance_normalisation: Perform MELODIC variance-normalisation on data.
        demean: Switch on de-meaning of design and data.
        nmf_dim: Number of underlying factors for NMF.
        nmf_iterations: Number of NMF iterations (default 100).
        verbose: Switch on verbose output.
        out_data: Output file name for pre-processed data.
        out_vnscales: Output file name for scaling factors for variance\
            normalisation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslMvlmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_MVLM_METADATA)
    cargs = []
    cargs.append("fsl_mvlm")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        basename_output_files
    ])
    if algorithm is not None:
        cargs.extend([
            "-a",
            algorithm
        ])
    if design_matrix is not None:
        cargs.extend([
            "-d",
            execution.input_file(design_matrix)
        ])
    if mask_image is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask_image)
        ])
    if design_normalization:
        cargs.append("--des_norm")
    if variance_normalisation:
        cargs.append("--vn")
    if demean:
        cargs.append("--demean")
    if nmf_dim is not None:
        cargs.extend([
            "--nmf_dim",
            str(nmf_dim)
        ])
    if nmf_iterations is not None:
        cargs.extend([
            "--nmfitt",
            str(nmf_iterations)
        ])
    if verbose:
        cargs.append("-v")
    if out_data is not None:
        cargs.extend([
            "--out_data",
            execution.input_file(out_data)
        ])
    if out_vnscales is not None:
        cargs.extend([
            "--out_vnscales",
            execution.input_file(out_vnscales)
        ])
    ret = FslMvlmOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(basename_output_files + "_out.nii.gz"),
        outdata=execution.output_file(pathlib.Path(out_data).name + ".nii.gz") if (out_data is not None) else None,
        vnscales=execution.output_file(pathlib.Path(out_vnscales).name + ".txt") if (out_vnscales is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_MVLM_METADATA",
    "FslMvlmOutputs",
    "fsl_mvlm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_JOINT_FUSION_METADATA = Metadata(
    id="e3c0355412de6dbc842f99d135c2be7604cb670d.boutiques",
    name="antsJointFusion",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsJointFusionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_joint_fusion(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_fusion_image: OutputPathType
    """The output label fusion image."""
    intensity_fusion_image: OutputPathType
    """The output intensity fusion image format."""
    label_posterior_probability_image: OutputPathType
    """The output label posterior probability image format."""
    atlas_voting_weight_image: OutputPathType
    """The output atlas voting weight image format."""


def ants_joint_fusion(
    target_image: list[InputPathType],
    atlas_image: list[InputPathType],
    atlas_segmentation: InputPathType,
    output: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    alpha: float | None = 0.1,
    beta: float | None = 2.0,
    constrain_nonnegative: typing.Literal[0, 1] | None = None,
    patch_radius: str | None = "2x2x2",
    patch_metric: typing.Literal["PC", "MSQ"] | None = "PC",
    search_radius: str | None = "3x3x3",
    exclusion_image: InputPathType | None = None,
    mask_image: InputPathType | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> AntsJointFusionOutputs:
    """
    antsJointFusion is an image fusion algorithm developed by Hongzhi Wang and Paul
    Yushkevich. This implementation is based on Paul's original ITK-style
    implementation and Brian's ANTsR implementation. The original label fusion
    framework was extended to accommodate intensities.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        target_image: The target image (or multimodal target images) assumed to\
            be aligned to a common image domain.
        atlas_image: The atlas image (or multimodal atlas images) assumed to be\
            aligned to a common image domain.
        atlas_segmentation: The atlas segmentation images. For performing label\
            fusion the number of specified segmentations should be identical to the\
            number of atlas image sets.
        output: The output is the intensity and/or label fusion image.\
            Additional optional outputs include the label posterior probability\
            images and the atlas voting weight images.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        alpha: Regularization term added to matrix Mx for calculating the\
            inverse. Default = 0.1.
        beta: Exponent for mapping intensity difference to the joint error.\
            Default = 2.0.
        constrain_nonnegative: Constrain solution to non-negative weights.
        patch_radius: Patch radius for similarity measures. Default = 2x2x2.
        patch_metric: Metric to be used in determining the most similar\
            neighborhood patch. Options include Pearson's correlation (PC) and mean\
            squares (MSQ). Default = PC (Pearson correlation).
        search_radius: Search radius for similarity measures. Default = 3x3x3.\
            One can also specify an image where the value at the voxel specifies\
            the isotropic search radius at that voxel.
        exclusion_image: Specify an exclusion region for the given label.
        mask_image: If a mask image is specified, fusion is only performed in\
            the mask region.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsJointFusionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_JOINT_FUSION_METADATA)
    cargs = []
    cargs.append("antsJointFusion")
    if image_dimensionality is not None:
        cargs.extend([
            "--image-dimensionality",
            str(image_dimensionality)
        ])
    cargs.extend([
        "--target-image",
        *[execution.input_file(f) for f in target_image]
    ])
    cargs.extend([
        "--atlas-image",
        *[execution.input_file(f) for f in atlas_image]
    ])
    cargs.extend([
        "--atlas-segmentation",
        execution.input_file(atlas_segmentation)
    ])
    if alpha is not None:
        cargs.extend([
            "--alpha",
            str(alpha)
        ])
    if beta is not None:
        cargs.extend([
            "--beta",
            str(beta)
        ])
    if constrain_nonnegative is not None:
        cargs.extend([
            "--constrain-nonnegative",
            str(constrain_nonnegative)
        ])
    if patch_radius is not None:
        cargs.extend([
            "--patch-radius",
            patch_radius
        ])
    if patch_metric is not None:
        cargs.extend([
            "--patch-metric",
            patch_metric
        ])
    if search_radius is not None:
        cargs.extend([
            "--search-radius",
            search_radius
        ])
    if exclusion_image is not None:
        cargs.extend([
            "--exclusion-image",
            execution.input_file(exclusion_image)
        ])
    if mask_image is not None:
        cargs.extend([
            "--mask-image",
            execution.input_file(mask_image)
        ])
    cargs.extend([
        "--output",
        output
    ])
    if verbose is not None:
        cargs.extend([
            "--verbose",
            str(verbose)
        ])
    ret = AntsJointFusionOutputs(
        root=execution.output_file("."),
        label_fusion_image=execution.output_file("[LABELFUSIONIMAGE]"),
        intensity_fusion_image=execution.output_file("[INTENSITYFUSIONIMAGEFILENAMEFORMAT]"),
        label_posterior_probability_image=execution.output_file("[LABELPOSTERIORPROBABILITYIMAGEFILENAMEFORMAT]"),
        atlas_voting_weight_image=execution.output_file("[ATLASVOTINGWEIGHTIMAGEFILENAMEFORMAT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_JOINT_FUSION_METADATA",
    "AntsJointFusionOutputs",
    "ants_joint_fusion",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GDFGLM_METADATA = Metadata(
    id="6bfd0a6b2b32f6fa09eb9767dc1f8e35ce2df1d6.boutiques",
    name="mri_gdfglm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGdfglmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gdfglm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outputs: OutputPathType
    """Output information is not available because the command has been
    removed."""


def mri_gdfglm(
    runner: Runner | None = None,
) -> MriGdfglmOutputs:
    """
    The mri_gdfglm command has been removed from the current version of FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGdfglmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GDFGLM_METADATA)
    cargs = []
    cargs.append("mri_gdfglm")
    ret = MriGdfglmOutputs(
        root=execution.output_file("."),
        outputs=execution.output_file("[OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GDFGLM_METADATA",
    "MriGdfglmOutputs",
    "mri_gdfglm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AFNITO_NIML_METADATA = Metadata(
    id="98f63f2e946d67b9373a37700e5abbc719dca8ea.boutiques",
    name="3dAFNItoNIML",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAfnitoNimlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_afnito_niml(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_afnito_niml(
    dset: InputPathType,
    runner: Runner | None = None,
) -> V3dAfnitoNimlOutputs:
    """
    Dumps AFNI dataset header information to stdout in NIML format. Mostly for
    debugging and testing purposes!.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dset: AFNI dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAfnitoNimlOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AFNITO_NIML_METADATA)
    cargs = []
    cargs.append("3dAFNItoNIML")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dset))
    ret = V3dAfnitoNimlOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAfnitoNimlOutputs",
    "V_3D_AFNITO_NIML_METADATA",
    "v_3d_afnito_niml",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BEDPOSTX_DATACHECK_METADATA = Metadata(
    id="eddcb6414c1d17da35164536bb565b595ac54640.boutiques",
    name="bedpostx_datacheck",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class BedpostxDatacheckOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bedpostx_datacheck(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def bedpostx_datacheck(
    data_dir: str,
    runner: Runner | None = None,
) -> BedpostxDatacheckOutputs:
    """
    Check the data directory for BEDPOSTX compatibility.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        data_dir: Data directory to check for BEDPOSTX compatibility.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BedpostxDatacheckOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BEDPOSTX_DATACHECK_METADATA)
    cargs = []
    cargs.append("bedpostx_datacheck")
    cargs.append(data_dir)
    ret = BedpostxDatacheckOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BEDPOSTX_DATACHECK_METADATA",
    "BedpostxDatacheckOutputs",
    "bedpostx_datacheck",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_CONVERT_DCM_ANAT_METADATA = Metadata(
    id="b710eae3e3dfce23951c6f5d44bae1dc65d2b536.boutiques",
    name="fat_proc_convert_dcm_anat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcConvertDcmAnatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_convert_dcm_anat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Converted anatomical volume output."""


def fat_proc_convert_dcm_anat(
    prefix: str,
    nifti_input: InputPathType | None = None,
    workdir: str | None = None,
    orient: str | None = None,
    no_clean: bool = False,
    reorig_reorient_off: bool = False,
    qc_prefix: str | None = None,
    no_cmd_out: bool = False,
    no_qc_view: bool = False,
    runner: Runner | None = None,
) -> FatProcConvertDcmAnatOutputs:
    """
    Converts an anatomical dataset from DICOM files into a volume, specifically
    designed to fit in line with other processing such as DTI analysis.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Set prefix (and path) for output data.
        nifti_input: Input as NIFTI file (zipped or unzipped fine). Alternative\
            to '-indir ..'.
        workdir: Specify a working directory, which can be removed (default\
            name = '__WORKING_convert_dcm_anat').
        orient: Optional chance to reset orientation of the volume files\
            (default is currently 'RAI').
        no_clean: Prevents removal of working directory.
        reorig_reorient_off: Turns off the nicety of putting (0, 0, 0) at\
            brain's center of mass (-> 'reorigin' calc) and reorienting data (->\
            'reorient' calc).
        qc_prefix: Set the prefix of the QC image files separately (default is\
            '').
        no_cmd_out: Don't save the command line call and the location where it\
            was run.
        no_qc_view: Turn off generating QC image files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcConvertDcmAnatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_CONVERT_DCM_ANAT_METADATA)
    cargs = []
    cargs.append("fat_proc_convert_dcm_anat")
    if nifti_input is not None:
        cargs.extend([
            "-innii",
            execution.input_file(nifti_input)
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if workdir is not None:
        cargs.extend([
            "-workdir",
            workdir
        ])
    if orient is not None:
        cargs.extend([
            "-orient",
            orient
        ])
    if no_clean:
        cargs.append("-no_clean")
    if reorig_reorient_off:
        cargs.append("-reorig_reorient_off")
    if qc_prefix is not None:
        cargs.extend([
            "-qc_prefix",
            qc_prefix
        ])
    if no_cmd_out:
        cargs.append("-no_cmd_out")
    if no_qc_view:
        cargs.append("-no_qc_view")
    ret = FatProcConvertDcmAnatOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_CONVERT_DCM_ANAT_METADATA",
    "FatProcConvertDcmAnatOutputs",
    "fat_proc_convert_dcm_anat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TENSOR2METRIC_METADATA = Metadata(
    id="ce3b6c1eb5966c84af85ddfef969868689c115fb.boutiques",
    name="tensor2metric",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Tensor2metricConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Tensor2metricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tensor2metric(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    adc: OutputPathType | None
    """compute the mean apparent diffusion coefficient (ADC) of the diffusion
    tensor. (sometimes also referred to as the mean diffusivity (MD)) """
    fa: OutputPathType | None
    """compute the fractional anisotropy (FA) of the diffusion tensor. """
    ad: OutputPathType | None
    """compute the axial diffusivity (AD) of the diffusion tensor. (equivalent
    to the principal eigenvalue) """
    rd: OutputPathType | None
    """compute the radial diffusivity (RD) of the diffusion tensor. (equivalent
    to the mean of the two non-principal eigenvalues) """
    cl: OutputPathType | None
    """compute the linearity metric of the diffusion tensor. (one of the three
    Westin shape metrics) """
    cp: OutputPathType | None
    """compute the planarity metric of the diffusion tensor. (one of the three
    Westin shape metrics) """
    cs: OutputPathType | None
    """compute the sphericity metric of the diffusion tensor. (one of the three
    Westin shape metrics) """
    value: OutputPathType | None
    """compute the selected eigenvalue(s) of the diffusion tensor. """
    vector: OutputPathType | None
    """compute the selected eigenvector(s) of the diffusion tensor. """


def tensor2metric(
    tensor: InputPathType,
    adc: str | None = None,
    fa: str | None = None,
    ad: str | None = None,
    rd: str | None = None,
    cl: str | None = None,
    cp: str | None = None,
    cs: str | None = None,
    value: str | None = None,
    vector: str | None = None,
    num: list[int] | None = None,
    modulate: str | None = None,
    mask: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Tensor2metricConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Tensor2metricOutputs:
    """
    Generate maps of tensor-derived parameters.
    
    
    
    References:
    
    Basser, P. J.; Mattiello, J. & Lebihan, D. MR diffusion tensor spectroscopy
    and imaging. Biophysical Journal, 1994, 66, 259-267
    
    Westin, C. F.; Peled, S.; Gudbjartsson, H.; Kikinis, R. & Jolesz, F. A.
    Geometrical diffusion measures for MRI from tensor basis analysis. Proc Intl
    Soc Mag Reson Med, 1997, 5, 1742.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        tensor: the input tensor image.
        adc: compute the mean apparent diffusion coefficient (ADC) of the\
            diffusion tensor. (sometimes also referred to as the mean diffusivity\
            (MD)).
        fa: compute the fractional anisotropy (FA) of the diffusion tensor.
        ad: compute the axial diffusivity (AD) of the diffusion tensor.\
            (equivalent to the principal eigenvalue).
        rd: compute the radial diffusivity (RD) of the diffusion tensor.\
            (equivalent to the mean of the two non-principal eigenvalues).
        cl: compute the linearity metric of the diffusion tensor. (one of the\
            three Westin shape metrics).
        cp: compute the planarity metric of the diffusion tensor. (one of the\
            three Westin shape metrics).
        cs: compute the sphericity metric of the diffusion tensor. (one of the\
            three Westin shape metrics).
        value: compute the selected eigenvalue(s) of the diffusion tensor.
        vector: compute the selected eigenvector(s) of the diffusion tensor.
        num: specify the desired eigenvalue/eigenvector(s). Note that several\
            eigenvalues can be specified as a number sequence. For example, '1,3'\
            specifies the principal (1) and minor (3) eigenvalues/eigenvectors\
            (default = 1).
        modulate: specify how to modulate the magnitude of the eigenvectors.\
            Valid choices are: none, FA, eigval (default = FA).
        mask: only perform computation within the specified binary brain mask\
            image.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Tensor2metricOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TENSOR2METRIC_METADATA)
    cargs = []
    cargs.append("tensor2metric")
    if adc is not None:
        cargs.extend([
            "-adc",
            adc
        ])
    if fa is not None:
        cargs.extend([
            "-fa",
            fa
        ])
    if ad is not None:
        cargs.extend([
            "-ad",
            ad
        ])
    if rd is not None:
        cargs.extend([
            "-rd",
            rd
        ])
    if cl is not None:
        cargs.extend([
            "-cl",
            cl
        ])
    if cp is not None:
        cargs.extend([
            "-cp",
            cp
        ])
    if cs is not None:
        cargs.extend([
            "-cs",
            cs
        ])
    if value is not None:
        cargs.extend([
            "-value",
            value
        ])
    if vector is not None:
        cargs.extend([
            "-vector",
            vector
        ])
    if num is not None:
        cargs.extend([
            "-num",
            *map(str, num)
        ])
    if modulate is not None:
        cargs.extend([
            "-modulate",
            modulate
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(tensor))
    ret = Tensor2metricOutputs(
        root=execution.output_file("."),
        adc=execution.output_file(adc) if (adc is not None) else None,
        fa=execution.output_file(fa) if (fa is not None) else None,
        ad=execution.output_file(ad) if (ad is not None) else None,
        rd=execution.output_file(rd) if (rd is not None) else None,
        cl=execution.output_file(cl) if (cl is not None) else None,
        cp=execution.output_file(cp) if (cp is not None) else None,
        cs=execution.output_file(cs) if (cs is not None) else None,
        value=execution.output_file(value) if (value is not None) else None,
        vector=execution.output_file(vector) if (vector is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TENSOR2METRIC_METADATA",
    "Tensor2metricConfig",
    "Tensor2metricOutputs",
    "tensor2metric",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FDRVAL_METADATA = Metadata(
    id="f92df9dc9c7bd351f5f06439c97a5434e22b31b8.boutiques",
    name="fdrval",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FdrvalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fdrval(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """Computed q-values or p-values for the given thresholds"""


def fdrval(
    dset: InputPathType,
    sub: float,
    val_list: list[float],
    pval: bool = False,
    ponly: bool = False,
    qonly: bool = False,
    qinput: bool = False,
    inverse: bool = False,
    runner: Runner | None = None,
) -> FdrvalOutputs:
    """
    Computes q-values from FDR curve data stored in dataset headers.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dset: Input dataset.
        sub: Sub-brick number.
        val_list: List of threshold values.
        pval: Output the p-value (on the same line, after q).
        ponly: Don't output q-values, just p-values.
        qonly: Don't output p-values, just q-values.
        qinput: The 'val' inputs are taken to be q-values and then the outputs\
            are the corresponding statistical thresholds.
        inverse: Inverse of the usual operation. 'Val' inputs must be between 0\
            and 1 (exclusive). Cannot be used with '-ponly' or '-pval'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FdrvalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FDRVAL_METADATA)
    cargs = []
    cargs.append("fdrval")
    cargs.append(execution.input_file(dset))
    cargs.append(str(sub))
    cargs.extend(map(str, val_list))
    if pval:
        cargs.append("-pval")
    if ponly:
        cargs.append("-ponly")
    if qonly:
        cargs.append("-qonly")
    if qinput:
        cargs.append("-qinput")
    if inverse:
        cargs.append("-inverse")
    ret = FdrvalOutputs(
        root=execution.output_file("."),
        output=execution.output_file("stdout.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FDRVAL_METADATA",
    "FdrvalOutputs",
    "fdrval",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LME_METADATA = Metadata(
    id="e9a80d6729c55d33424066db0a326673e6b70516.boutiques",
    name="3dLME",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLmeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_lme(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_nifti: OutputPathType
    """Output file in NIfTI format"""


def v_3d_lme(
    prefix: str,
    model: str,
    data_table: str,
    bounds: list[float] | None = None,
    cio_flag: bool = False,
    cor_str: str | None = None,
    cutoff: float | None = None,
    dbg_args_flag: bool = False,
    jobs: float | None = None,
    glt_code: str | None = None,
    glt_label: str | None = None,
    glf_label: str | None = None,
    glf_code: str | None = None,
    icc_flag: bool = False,
    iccb_flag: bool = False,
    log_lik_flag: bool = False,
    logit_flag: bool = False,
    ml_flag: bool = False,
    qvars_centers: str | None = None,
    qvars: str | None = None,
    raneff: str | None = None,
    mask: InputPathType | None = None,
    num_glf: float | None = None,
    num_glt: float | None = None,
    resid: str | None = None,
    re_: str | None = None,
    reprefix: str | None = None,
    rio_flag: bool = False,
    show_options_flag: bool = False,
    ss_type: float | None = None,
    runner: Runner | None = None,
) -> V3dLmeOutputs:
    """
    AFNI Group Analysis Program with Linear Mixed-Effects Modeling Approach.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Prefix for output files.
        model: Model formula describing the fixed effects.
        data_table: Data table description.
        bounds: Lower and upper bounds for outlier removal.
        cio_flag: Use AFNI's C io functions (default) or R's io functions with\
            -Rio.
        cor_str: Specify the correlation structure of the residuals.
        cutoff: Specify the cutoff value for accuracy in logistic regression\
            analysis.
        dbg_args_flag: Enable saving parameters for debugging.
        jobs: Number of jobs for parallel computing.
        glt_code: General linear test coding.
        glt_label: Label for general linear test.
        glf_label: Label for general linear F-test.
        glf_code: General linear F-test coding.
        icc_flag: Compute voxel-wise intra-class correlation.
        iccb_flag: Compute voxel-wise intra-class correlation with Bayesian\
            approach.
        log_lik_flag: Include voxel-wise log likelihood in the output.
        logit_flag: Perform voxel-wise logistic modeling.
        ml_flag: Use Maximum Likelihood estimation instead of REML.
        qvars_centers: Centering values for quantitative variables.
        qvars: Identify quantitative variables (or covariates).
        raneff: Specify the random effects.
        mask: Mask file for voxel processing.
        num_glf: Number of general linear F-tests.
        num_glt: Number of general linear t-tests.
        resid: Prefix for residuals output file.
        re_: List of variables whose random effects are saved in the output.
        reprefix: Prefix for random effects output file.
        rio_flag: Use R's io functions instead of AFNI's C io functions.
        show_options_flag: List of allowed options.
        ss_type: Specify the type for sums of squares in the F-statistics.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLmeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LME_METADATA)
    cargs = []
    cargs.append("3dLME")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-model",
        model
    ])
    cargs.extend([
        "-dataTable",
        data_table
    ])
    if bounds is not None:
        cargs.extend([
            "-bounds",
            *map(str, bounds)
        ])
    if cio_flag:
        cargs.append("-cio")
    if cor_str is not None:
        cargs.extend([
            "-corStr",
            cor_str
        ])
    if cutoff is not None:
        cargs.extend([
            "-cutoff",
            str(cutoff)
        ])
    if dbg_args_flag:
        cargs.append("-dbgArgs")
    if jobs is not None:
        cargs.extend([
            "-jobs",
            str(jobs)
        ])
    if glt_code is not None:
        cargs.extend([
            "-gltCode",
            glt_code
        ])
    if glt_label is not None:
        cargs.extend([
            "-gltLabel",
            glt_label
        ])
    if glf_label is not None:
        cargs.extend([
            "-glfLabel",
            glf_label
        ])
    if glf_code is not None:
        cargs.extend([
            "-glfCode",
            glf_code
        ])
    if icc_flag:
        cargs.append("-ICC")
    if iccb_flag:
        cargs.append("-ICCb")
    if log_lik_flag:
        cargs.append("-logLik")
    if logit_flag:
        cargs.append("-LOGIT")
    cargs.append("-ml")
    if ml_flag:
        cargs.append("-ML")
    if qvars_centers is not None:
        cargs.extend([
            "-qVarsCenters",
            qvars_centers
        ])
    if qvars is not None:
        cargs.extend([
            "-qVars",
            qvars
        ])
    if raneff is not None:
        cargs.extend([
            "-ranEff",
            raneff
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if num_glf is not None:
        cargs.extend([
            "-num_glf",
            str(num_glf)
        ])
    if num_glt is not None:
        cargs.extend([
            "-num_glt",
            str(num_glt)
        ])
    if resid is not None:
        cargs.extend([
            "-resid",
            resid
        ])
    if re_ is not None:
        cargs.extend([
            "-RE",
            re_
        ])
    if reprefix is not None:
        cargs.extend([
            "-REprefix",
            reprefix
        ])
    cargs.append("-RIO")
    if rio_flag:
        cargs.append("-Rio")
    if show_options_flag:
        cargs.append("-show_allowed_options")
    if ss_type is not None:
        cargs.extend([
            "-SS_type",
            str(ss_type)
        ])
    ret = V3dLmeOutputs(
        root=execution.output_file("."),
        output_nifti=execution.output_file(prefix + ".nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLmeOutputs",
    "V_3D_LME_METADATA",
    "v_3d_lme",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ZERO_LT_4DFP_METADATA = Metadata(
    id="5af9fb53b5beb7937f30eebe316bb87929b7202b.boutiques",
    name="zero_lt_4dfp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ZeroLt4dfpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `zero_lt_4dfp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_4dfp: OutputPathType | None
    """Output 4dfp file with values less than the threshold zeroed."""


def zero_lt_4dfp(
    flt_value: float,
    file_4dfp: InputPathType,
    outroot: str | None = None,
    endianness: str | None = None,
    runner: Runner | None = None,
) -> ZeroLt4dfpOutputs:
    """
    A tool to process 4dfp image files by zeroing values less than a given float
    threshold.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        flt_value: Floating point threshold value. Values less than this in the\
            4dfp file will be zeroed.
        file_4dfp: Input 4dfp file.
        outroot: Output root name for 4dfp file. If not specified, defaults to\
            input file root with 'z' appended.
        endianness: Specify output endian format: 'b' for big endian or 'l' for\
            little endian. Defaults to input endian.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZeroLt4dfpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ZERO_LT_4DFP_METADATA)
    cargs = []
    cargs.append("zero_lt_4dfp")
    cargs.append(str(flt_value))
    cargs.append(execution.input_file(file_4dfp))
    if outroot is not None:
        cargs.append(outroot)
    if endianness is not None:
        cargs.extend([
            "-@",
            endianness
        ])
    ret = ZeroLt4dfpOutputs(
        root=execution.output_file("."),
        output_4dfp=execution.output_file(outroot + ".4dfp") if (outroot is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ZERO_LT_4DFP_METADATA",
    "ZeroLt4dfpOutputs",
    "zero_lt_4dfp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SURF2VOL_METADATA = Metadata(
    id="750ed03dd5a1fd4b3541f1778bd76f62c8dcfbba.boutiques",
    name="mri_surf2vol",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSurf2volOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_surf2vol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Output volume with resampled surface"""
    vertex_volume: OutputPathType | None
    """Vertex map volume indicating mapped voxels"""


def mri_surf2vol(
    outfile: str,
    surface_overlay: list[str] | None = None,
    ltafile: InputPathType | None = None,
    subject: str | None = None,
    ribbonfile: InputPathType | None = None,
    merge_volume: InputPathType | None = None,
    surface_values: str | None = None,
    mkmask: bool = False,
    hemi: str | None = None,
    surfname: str | None = None,
    projfrac: float | None = None,
    fill_ribbon: bool = False,
    fill_projfrac: str | None = None,
    reg_volume: InputPathType | None = None,
    identity: str | None = None,
    template_volume: InputPathType | None = None,
    fstal_res: str | None = None,
    vtxvol: InputPathType | None = None,
    flat2mri: str | None = None,
    sphpvf: str | None = None,
    mask_to_cortex: bool = False,
    mask_to_label: InputPathType | None = None,
    surface_mask: InputPathType | None = None,
    add_const: float | None = None,
    copy_ctab: bool = False,
    subjects_dir: str | None = None,
    gdiagno: int | None = None,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> MriSurf2volOutputs:
    """
    Resamples a surface into a volume using one of two methods.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        outfile: Path to output volume.
        surface_overlay: Specify path to a surface and matching overlay.
        ltafile: Specify registration file.
        subject: Specify subject name.
        ribbonfile: Specify path to ribbon file.
        merge_volume: Merge with this volume, replacing surface values.
        surface_values: Source of surface values, optionally with format.
        mkmask: Create a binary mask instead of loading surfval.
        hemi: Hemisphere for the surface values (lh or rh).
        surfname: Surface name in surf directory (default is white).
        projfrac: Fraction for thickness projection.
        fill_ribbon: Fill the entire ribbon.
        fill_projfrac: Fill ribbon by iterating projfrac.
        reg_volume: Volume registration file.
        identity: Use identity matrix for volume registration (requires subject\
            name).
        template_volume: Template volume for output configuration.
        fstal_res: Use fs Talairach registration with specified resolution.
        vtxvol: Vertex map volume path.
        flat2mri: Options for flat surface to MRI mapping.
        sphpvf: Spherical point to voxel function options.
        mask_to_cortex: Mask to cortex label.
        mask_to_label: Mask to specified label file.
        surface_mask: Mask to specified surface mask.
        add_const: Add constant value to each non-zero output voxel.
        copy_ctab: Copy color table header.
        subjects_dir: FreeSurfer subjects directory.
        gdiagno: Set diagnostic level.
        version: Print version and exit.
        help_: Display help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSurf2volOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SURF2VOL_METADATA)
    cargs = []
    cargs.append("mri_surf2vol")
    if surface_overlay is not None:
        cargs.extend([
            "--so",
            *surface_overlay
        ])
    if ltafile is not None:
        cargs.extend([
            "--lta",
            execution.input_file(ltafile)
        ])
    cargs.extend([
        "--o",
        outfile
    ])
    if subject is not None:
        cargs.extend([
            "--subject",
            subject
        ])
    if ribbonfile is not None:
        cargs.extend([
            "--ribbon",
            execution.input_file(ribbonfile)
        ])
    if merge_volume is not None:
        cargs.extend([
            "--merge",
            execution.input_file(merge_volume)
        ])
    if surface_values is not None:
        cargs.extend([
            "--surfval",
            surface_values
        ])
    if mkmask:
        cargs.append("--mkmask")
    if hemi is not None:
        cargs.extend([
            "--hemi",
            hemi
        ])
    if surfname is not None:
        cargs.extend([
            "--surf",
            surfname
        ])
    if projfrac is not None:
        cargs.extend([
            "--projfrac",
            str(projfrac)
        ])
    if fill_ribbon:
        cargs.append("--fillribbon")
    if fill_projfrac is not None:
        cargs.extend([
            "--fill-projfrac",
            fill_projfrac
        ])
    if reg_volume is not None:
        cargs.extend([
            "--reg",
            execution.input_file(reg_volume)
        ])
    if identity is not None:
        cargs.extend([
            "--identity",
            identity
        ])
    if template_volume is not None:
        cargs.extend([
            "--template",
            execution.input_file(template_volume)
        ])
    if fstal_res is not None:
        cargs.extend([
            "--fstal",
            fstal_res
        ])
    if vtxvol is not None:
        cargs.extend([
            "--vtxvol",
            execution.input_file(vtxvol)
        ])
    if flat2mri is not None:
        cargs.extend([
            "--flat2mri",
            flat2mri
        ])
    if sphpvf is not None:
        cargs.extend([
            "--sphpvf",
            sphpvf
        ])
    if mask_to_cortex:
        cargs.append("--mask-to-cortex")
    if mask_to_label is not None:
        cargs.extend([
            "--mask-to-label",
            execution.input_file(mask_to_label)
        ])
    if surface_mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(surface_mask)
        ])
    if add_const is not None:
        cargs.extend([
            "--add",
            str(add_const)
        ])
    if copy_ctab:
        cargs.append("--copy-ctab")
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if gdiagno is not None:
        cargs.extend([
            "--gdiagno",
            str(gdiagno)
        ])
    if version:
        cargs.append("--version")
    if help_:
        cargs.append("--help")
    ret = MriSurf2volOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(outfile),
        vertex_volume=execution.output_file(pathlib.Path(vtxvol).name) if (vtxvol is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SURF2VOL_METADATA",
    "MriSurf2volOutputs",
    "mri_surf2vol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TCKMAP_METADATA = Metadata(
    id="20fc0eb1cf1e5881a0131f8a9755f1e2d22946f9.boutiques",
    name="tckmap",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TckmapVariousString:
    obj: str
    """String object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.obj)
        return cargs


@dataclasses.dataclass
class TckmapVariousFile:
    obj: InputPathType
    """File object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.obj))
        return cargs


@dataclasses.dataclass
class TckmapConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TckmapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tckmap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output track-weighted image"""


def tckmap(
    tracks: InputPathType,
    output: str,
    template: InputPathType | None = None,
    vox: list[float] | None = None,
    datatype: str | None = None,
    dec: bool = False,
    dixel: typing.Union[TckmapVariousString, TckmapVariousFile] | None = None,
    tod: int | None = None,
    contrast: str | None = None,
    image: InputPathType | None = None,
    vector_file: InputPathType | None = None,
    stat_vox: str | None = None,
    stat_tck: str | None = None,
    fwhm_tck: float | None = None,
    map_zero: bool = False,
    backtrack: bool = False,
    upsample: int | None = None,
    precise: bool = False,
    ends_only: bool = False,
    tck_weights_in: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TckmapConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TckmapOutputs:
    """
    Use track data as a form of contrast for producing a high-resolution image.
    
    Note: if you run into limitations with RAM usage, make sure you output the
    results to a .mif file or .mih / .dat file pair - this will avoid the
    allocation of an additional buffer to store the output for write-out.
    
    References:
    
    * For TDI or DEC TDI:
    Calamante, F.; Tournier, J.-D.; Jackson, G. D. & Connelly, A. Track-density
    imaging (TDI): Super-resolution white matter imaging using whole-brain
    track-density mapping. NeuroImage, 2010, 53, 1233-1243
    
    * If using -contrast length and -stat_vox mean:
    Pannek, K.; Mathias, J. L.; Bigler, E. D.; Brown, G.; Taylor, J. D. & Rose,
    S. E. The average pathlength map: A diffusion MRI tractography-derived index
    for studying brain pathology. NeuroImage, 2011, 55, 133-141
    
    * If using -dixel option with TDI contrast only:
    Smith, R.E., Tournier, J-D., Calamante, F., Connelly, A. A novel paradigm
    for automated segmentation of very large whole-brain probabilistic
    tractography data sets. In proc. ISMRM, 2011, 19, 673
    
    * If using -dixel option with any other contrast:
    Pannek, K., Raffelt, D., Salvado, O., Rose, S. Incorporating directional
    information in diffusion tractography derived maps: angular track imaging
    (ATI). In Proc. ISMRM, 2012, 20, 1912
    
    * If using -tod option:
    Dhollander, T., Emsell, L., Van Hecke, W., Maes, F., Sunaert, S., Suetens,
    P. Track Orientation Density Imaging (TODI) and Track Orientation
    Distribution (TOD) based tractography. NeuroImage, 2014, 94, 312-336
    
    * If using other contrasts / statistics:
    Calamante, F.; Tournier, J.-D.; Smith, R. E. & Connelly, A. A generalised
    framework for super-resolution track-weighted imaging. NeuroImage, 2012, 59,
    2494-2503
    
    * If using -precise mapping option:
    Smith, R. E.; Tournier, J.-D.; Calamante, F. & Connelly, A. SIFT:
    Spherical-deconvolution informed filtering of tractograms. NeuroImage, 2013,
    67, 298-312 (Appendix 3).
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        tracks: the input track file.
        output: the output track-weighted image.
        template: an image file to be used as a template for the output (the\
            output image will have the same transform and field of view).
        vox: provide either an isotropic voxel size (in mm), or comma-separated\
            list of 3 voxel dimensions.
        datatype: specify output image data type.
        dec: perform track mapping in directionally-encoded colour (DEC) space.
        dixel: map streamlines to dixels within each voxel; requires either a\
            number of dixels (references an internal direction set), or a path to a\
            text file containing a set of directions stored as azimuth/elevation\
            pairs.
        tod: generate a Track Orientation Distribution (TOD) in each voxel;\
            need to specify the maximum spherical harmonic degree lmax to use when\
            generating Apodised Point Spread Functions.
        contrast: define the desired form of contrast for the output image\
            Options are: tdi, length, invlength, scalar_map, scalar_map_count,\
            fod_amp, curvature, vector_file (default: tdi).
        image: provide the scalar image map for generating images with\
            'scalar_map' / 'scalar_map_count' contrast, or the spherical harmonics\
            image for 'fod_amp' contrast.
        vector_file: provide the vector data file for generating images with\
            'vector_file' contrast.
        stat_vox: define the statistic for choosing the final voxel intensities\
            for a given contrast type given the individual values from the tracks\
            passing through each voxel.\
            Options are: sum, min, mean, max (default: sum).
        stat_tck: define the statistic for choosing the contribution to be made\
            by each streamline as a function of the samples taken along their\
            lengths.\
            Only has an effect for 'scalar_map', 'fod_amp' and 'curvature'\
            contrast types.\
            Options are: sum, min, mean, max, median, mean_nonzero, gaussian,\
            ends_min, ends_mean, ends_max, ends_prod (default: mean).
        fwhm_tck: when using gaussian-smoothed per-track statistic, specify the\
            desired full-width half-maximum of the Gaussian smoothing kernel (in\
            mm).
        map_zero: if a streamline has zero contribution based on the contrast &\
            statistic, typically it is not mapped; use this option to still\
            contribute to the map even if this is the case (these non-contributing\
            voxels can then influence the mean value in each voxel of the map).
        backtrack: when using -stat_tck ends_*, if the streamline endpoint is\
            outside the FoV, backtrack along the streamline trajectory until an\
            appropriate point is found.
        upsample: upsample the tracks by some ratio using Hermite interpolation\
            before mappping\
            (If omitted, an appropriate ratio will be determined automatically).
        precise: use a more precise streamline mapping strategy, that\
            accurately quantifies the length through each voxel (these lengths are\
            then taken into account during TWI calculation).
        ends_only: only map the streamline endpoints to the image.
        tck_weights_in: specify a text scalar file containing the streamline\
            weights.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TckmapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TCKMAP_METADATA)
    cargs = []
    cargs.append("tckmap")
    if template is not None:
        cargs.extend([
            "-template",
            execution.input_file(template)
        ])
    if vox is not None:
        cargs.extend([
            "-vox",
            ",".join(map(str, vox))
        ])
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if dec:
        cargs.append("-dec")
    if dixel is not None:
        cargs.extend([
            "-dixel",
            *dixel.run(execution)
        ])
    if tod is not None:
        cargs.extend([
            "-tod",
            str(tod)
        ])
    if contrast is not None:
        cargs.extend([
            "-contrast",
            contrast
        ])
    if image is not None:
        cargs.extend([
            "-image",
            execution.input_file(image)
        ])
    if vector_file is not None:
        cargs.extend([
            "-vector_file",
            execution.input_file(vector_file)
        ])
    if stat_vox is not None:
        cargs.extend([
            "-stat_vox",
            stat_vox
        ])
    if stat_tck is not None:
        cargs.extend([
            "-stat_tck",
            stat_tck
        ])
    if fwhm_tck is not None:
        cargs.extend([
            "-fwhm_tck",
            str(fwhm_tck)
        ])
    if map_zero:
        cargs.append("-map_zero")
    if backtrack:
        cargs.append("-backtrack")
    if upsample is not None:
        cargs.extend([
            "-upsample",
            str(upsample)
        ])
    if precise:
        cargs.append("-precise")
    if ends_only:
        cargs.append("-ends_only")
    if tck_weights_in is not None:
        cargs.extend([
            "-tck_weights_in",
            execution.input_file(tck_weights_in)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(tracks))
    cargs.append(output)
    ret = TckmapOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TCKMAP_METADATA",
    "TckmapConfig",
    "TckmapOutputs",
    "TckmapVariousFile",
    "TckmapVariousString",
    "tckmap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DRENAME_METADATA = Metadata(
    id="3c508d8f5e6d69689dd267857ef13efbf3693249.boutiques",
    name="3drename",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3drenameOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3drename(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3drename(
    old_prefix: str,
    new_prefix: str,
    runner: Runner | None = None,
) -> V3drenameOutputs:
    """
    Tool to rename AFNI datasets by changing the dataset prefix.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        old_prefix: Old prefix of the datasets to rename.
        new_prefix: New prefix for the datasets.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3drenameOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DRENAME_METADATA)
    cargs = []
    cargs.append("3drename")
    cargs.append(old_prefix)
    cargs.append(new_prefix)
    ret = V3drenameOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3drenameOutputs",
    "V_3DRENAME_METADATA",
    "v_3drename",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

COMPUTE_INTERRATER_VARIABILITY_CSH_METADATA = Metadata(
    id="d85f89519ecdd6db050cf20b230dd279bab615ca.boutiques",
    name="compute_interrater_variability.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ComputeInterraterVariabilityCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `compute_interrater_variability_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file_1: OutputPathType
    """Output file containing mean Hausdorff distance."""
    output_file_2: OutputPathType
    """Output file containing max Hausdorff distance."""
    output_file_3: OutputPathType
    """Output file containing label volume difference, Dice, and Jaccard overlap
    measures."""


def compute_interrater_variability_csh(
    label_vol1: InputPathType,
    label_vol2: InputPathType,
    output_prefix: str,
    runner: Runner | None = None,
) -> ComputeInterraterVariabilityCshOutputs:
    """
    Computes the interrater variability between label volumes from different raters
    or time points using several metrics.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        label_vol1: Label volume from rater 1.
        label_vol2: Label volume from rater 2.
        output_prefix: Prefix for the output text files containing results. A\
            total of three files will be produced.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ComputeInterraterVariabilityCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(COMPUTE_INTERRATER_VARIABILITY_CSH_METADATA)
    cargs = []
    cargs.append("compute_interrater_variability")
    cargs.extend([
        "--vol1",
        execution.input_file(label_vol1)
    ])
    cargs.extend([
        "--vol2",
        execution.input_file(label_vol2)
    ])
    cargs.extend([
        "--out",
        output_prefix
    ])
    ret = ComputeInterraterVariabilityCshOutputs(
        root=execution.output_file("."),
        output_file_1=execution.output_file(output_prefix + "_file1.txt"),
        output_file_2=execution.output_file(output_prefix + "_file2.txt"),
        output_file_3=execution.output_file(output_prefix + "_file3.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "COMPUTE_INTERRATER_VARIABILITY_CSH_METADATA",
    "ComputeInterraterVariabilityCshOutputs",
    "compute_interrater_variability_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEG2RECON_METADATA = Metadata(
    id="36dfabf1fcfdc6c0dea237cf9f3d8968bf6ef6bc.boutiques",
    name="seg2recon",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Seg2reconOutputs(typing.NamedTuple):
    """
    Output object returned when calling `seg2recon(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aseg_auto_mgz: OutputPathType
    """Output aseg.auto.mgz file including corpus callosum segmentation"""
    nu_mgz: OutputPathType
    """Bias field corrected output nu.mgz file"""
    brainmask_mgz: OutputPathType
    """Output brainmask.mgz file"""


def seg2recon(
    subject: str,
    segvol: InputPathType,
    inputvol: InputPathType,
    ctab: InputPathType | None = None,
    ndilate: float | None = None,
    threads: float | None = None,
    force_update: bool = False,
    no_cc: bool = False,
    mask: InputPathType | None = None,
    headmask: InputPathType | None = None,
    thresh: float | None = None,
    expert: InputPathType | None = None,
    rca: bool = False,
    no_bias_field_cor: bool = False,
    runner: Runner | None = None,
) -> Seg2reconOutputs:
    """
    Creates and populates a subjects directory from an input image and segmentation
    suitable for running recon-all.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Output subject directory name.
        segvol: Aseg-type volume, e.g., from synthseg, fastsurfer, psacnn,\
            samseg, or aseg.
        inputvol: Input volume as would be passed to recon-all.
        ctab: Color table for the segmentation. Uses embedded table if\
            available, or FreeSurferColorLUT.txt if not specified.
        ndilate: Dilate binarization of segmentation when creating brainmask.\
            Default is 2.
        threads: Number of threads to use for processing.
        force_update: Force regeneration of files whether needed or not.
        no_cc: Do not segment corpus callosum.
        mask: Use this mask as brainmask instead of computing from\
            segmentation.
        headmask: Use this headmask instead of running mri_seghead.
        thresh: Threshold for bias field estimation.
        expert: Path to expert options file.
        rca: Run recon-all on the output.
        no_bias_field_cor: Do not compute or apply bias field correction.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Seg2reconOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEG2RECON_METADATA)
    cargs = []
    cargs.append("seg2recon")
    cargs.extend([
        "-s",
        subject
    ])
    cargs.extend([
        "-seg",
        execution.input_file(segvol)
    ])
    cargs.extend([
        "-i",
        execution.input_file(inputvol)
    ])
    if ctab is not None:
        cargs.extend([
            "-ctab",
            execution.input_file(ctab)
        ])
    if ndilate is not None:
        cargs.extend([
            "--ndilate",
            str(ndilate)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if force_update:
        cargs.append("--force-update")
    if no_cc:
        cargs.append("--no-cc")
    if mask is not None:
        cargs.extend([
            "--m",
            execution.input_file(mask)
        ])
    if headmask is not None:
        cargs.extend([
            "--h",
            execution.input_file(headmask)
        ])
    if thresh is not None:
        cargs.extend([
            "--thresh",
            str(thresh)
        ])
    if expert is not None:
        cargs.extend([
            "--expert",
            execution.input_file(expert)
        ])
    if rca:
        cargs.append("--rca")
    if no_bias_field_cor:
        cargs.append("--no-bias-field-cor")
    ret = Seg2reconOutputs(
        root=execution.output_file("."),
        aseg_auto_mgz=execution.output_file(subject + "/aseg.auto.mgz"),
        nu_mgz=execution.output_file(subject + "/nu.mgz"),
        brainmask_mgz=execution.output_file(subject + "/brainmask.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEG2RECON_METADATA",
    "Seg2reconOutputs",
    "seg2recon",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICETIMER_FSL_METADATA = Metadata(
    id="27673c86089b795cd88a005218734e798ec23211.boutiques",
    name="slicetimer.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SlicetimerFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slicetimer_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_timeseries: OutputPathType | None
    """Corrected output timeseries"""


def slicetimer_fsl(
    infile: InputPathType,
    outfile: str | None = None,
    tr: float | None = None,
    direction: typing.Literal["x", "y", "z"] | None = None,
    interleaved: bool = False,
    reverse: bool = False,
    custom_timings: InputPathType | None = None,
    global_shift: float | None = None,
    custom_interleave_order: InputPathType | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> SlicetimerFslOutputs:
    """
    FMRIB's Interpolation for Slice Timing correction in FMRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Filename of input timeseries.
        outfile: Filename of output corrected timeseries.
        tr: Specify TR of data, default is 3s.
        direction: Direction of slice acquisition (x=1, y=2, z=3); default is z.
        interleaved: Use interleaved acquisition.
        reverse: Reverse slice indexing (default is slices were acquired\
            bottom-up).
        custom_timings: Filename of single-column slice timings in fractions of\
            TR, positive values shift slices forwards in time.
        global_shift: Global shift in fraction of TR, default is 0.
        custom_interleave_order: Filename of single-column custom interleave\
            order file (first slice is referred to as 1 not 0).
        verbose: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SlicetimerFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICETIMER_FSL_METADATA)
    cargs = []
    cargs.append("slicetimer")
    cargs.append("--in")
    cargs.extend([
        "-i",
        execution.input_file(infile)
    ])
    if outfile is not None:
        cargs.extend([
            "-o",
            outfile
        ])
    if tr is not None:
        cargs.extend([
            "-r",
            str(tr)
        ])
    if direction is not None:
        cargs.extend([
            "-d",
            direction
        ])
    if interleaved:
        cargs.append("--odd")
    if reverse:
        cargs.append("--down")
    if custom_timings is not None:
        cargs.extend([
            "--tcustom",
            execution.input_file(custom_timings)
        ])
    if global_shift is not None:
        cargs.extend([
            "--tglobal",
            str(global_shift)
        ])
    if custom_interleave_order is not None:
        cargs.extend([
            "--ocustom",
            execution.input_file(custom_interleave_order)
        ])
    if verbose:
        cargs.append("-v")
    ret = SlicetimerFslOutputs(
        root=execution.output_file("."),
        corrected_timeseries=execution.output_file(outfile) if (outfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICETIMER_FSL_METADATA",
    "SlicetimerFslOutputs",
    "slicetimer_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RECON_ALL_CLINICAL_SH_METADATA = Metadata(
    id="38aa6da8e0504acf21091c65fc76ff6026418cb2.boutiques",
    name="recon-all-clinical.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ReconAllClinicalShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `recon_all_clinical_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def recon_all_clinical_sh(
    input_scan: InputPathType,
    subject_id: str,
    threads: int,
    subject_dir: str | None = None,
    runner: Runner | None = None,
) -> ReconAllClinicalShOutputs:
    """
    Recon-all-like stream for processing clinical brain MRI scans of arbitrary
    orientation, resolution, and contrast using SynthSeg and SynthSR.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_scan: Input scan file to be processed.
        subject_id: Identifier for the subject being processed.
        threads: Number of threads to use for processing.
        subject_dir: Optional subjects directory. Only necessary if the\
            environment variable SUBJECTS_DIR is not set or needs to be overridden.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ReconAllClinicalShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RECON_ALL_CLINICAL_SH_METADATA)
    cargs = []
    cargs.append("recon-all-clinical.sh")
    cargs.append(execution.input_file(input_scan))
    cargs.append(subject_id)
    cargs.append(str(threads))
    if subject_dir is not None:
        cargs.append(subject_dir)
    ret = ReconAllClinicalShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RECON_ALL_CLINICAL_SH_METADATA",
    "ReconAllClinicalShOutputs",
    "recon_all_clinical_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ENTROPY_METADATA = Metadata(
    id="65268d877950e23f9bd06dfb7ede10b57050e1e9.boutiques",
    name="3dEntropy",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dEntropyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_entropy(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_entropy(
    input_dataset: InputPathType,
    zskip: bool = False,
    runner: Runner | None = None,
) -> V3dEntropyOutputs:
    """
    Computes entropy for a 3D dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input dataset (stored as 16 bit shorts).
        zskip: Skip 0 values in the entropy computation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dEntropyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ENTROPY_METADATA)
    cargs = []
    cargs.append("3dEntropy")
    if zskip:
        cargs.append("-zskip")
    cargs.append(execution.input_file(input_dataset))
    ret = V3dEntropyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dEntropyOutputs",
    "V_3D_ENTROPY_METADATA",
    "v_3d_entropy",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EXPORT_GCAM_METADATA = Metadata(
    id="71849e2de237c64059ec889d31c3f9a65e91dede.boutiques",
    name="exportGcam",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ExportGcamOutputs(typing.NamedTuple):
    """
    Output object returned when calling `export_gcam(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_gcam_file: OutputPathType
    """Output GCAM file."""


def export_gcam(
    fixed: InputPathType,
    moving: InputPathType,
    morph: InputPathType,
    out_gcam: InputPathType,
    zlib_buffer: float | None = None,
    bbox_threshold: float | None = None,
    interp_method: typing.Literal["linear", "nearest"] | None = "linear",
    test: bool = False,
    runner: Runner | None = None,
) -> ExportGcamOutputs:
    """
    A tool for exporting GCAM (Geodesic Coordinate-based Anatomic Mapping) morphs.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        fixed: Fixed volume.
        moving: Moving volume.
        morph: Morph.
        out_gcam: Output GCAM (Geodesic Coordinate-based Anatomic Mapping).
        zlib_buffer: Zlib buffer pre-allocation multiplier.
        bbox_threshold: Threshold for bounding box. If absent, no bbox will be\
            used.
        interp_method: Interpolation method. Choices: linear, nearest. Default\
            is linear.
        test: Write out test files to verify the equivalence of tm3d and gcam\
            morphs.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ExportGcamOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EXPORT_GCAM_METADATA)
    cargs = []
    cargs.append("exportGcam")
    cargs.extend([
        "--fixed",
        execution.input_file(fixed)
    ])
    cargs.extend([
        "--moving",
        execution.input_file(moving)
    ])
    cargs.extend([
        "--morph",
        execution.input_file(morph)
    ])
    cargs.extend([
        "--out_gcam",
        execution.input_file(out_gcam)
    ])
    if zlib_buffer is not None:
        cargs.extend([
            "--zlib_buffer",
            str(zlib_buffer)
        ])
    if bbox_threshold is not None:
        cargs.extend([
            "--bbox_threshold",
            str(bbox_threshold)
        ])
    if interp_method is not None:
        cargs.extend([
            "--interp",
            interp_method
        ])
    if test:
        cargs.append("--test")
    ret = ExportGcamOutputs(
        root=execution.output_file("."),
        output_gcam_file=execution.output_file(pathlib.Path(out_gcam).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EXPORT_GCAM_METADATA",
    "ExportGcamOutputs",
    "export_gcam",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMGREG_4DFP_METADATA = Metadata(
    id="56f755f16ccfb6ca990d0bdefae3bf38a4194227.boutiques",
    name="imgreg_4dfp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Imgreg4dfpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imgreg_4dfp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def imgreg_4dfp(
    target_image: InputPathType,
    source_image: InputPathType,
    t4file: str,
    mode: str,
    target_mask: str = "none",
    source_mask: str = "none",
    runner: Runner | None = None,
) -> Imgreg4dfpOutputs:
    """
    Image registration utility using 4dfp.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        target_image: Target image.
        source_image: Source image.
        t4file: Transformation file.
        mode: Mode of operation.
        target_mask: Target mask.
        source_mask: Source mask.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Imgreg4dfpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMGREG_4DFP_METADATA)
    cargs = []
    cargs.append("imgreg_4dfp")
    cargs.append(execution.input_file(target_image))
    cargs.append(target_mask)
    cargs.append(execution.input_file(source_image))
    cargs.append(source_mask)
    cargs.append(t4file)
    cargs.append(mode)
    ret = Imgreg4dfpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMGREG_4DFP_METADATA",
    "Imgreg4dfpOutputs",
    "imgreg_4dfp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BUGR_METADATA = Metadata(
    id="61b1c8588fe75d759f05f238db179fab105dd284.boutiques",
    name="bugr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BugrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bugr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def bugr(
    subject_name: str,
    command_line: str,
    error_message: str,
    log_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> BugrOutputs:
    """
    Utility for generating and reporting FreeSurfer bugs.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Subject name to include in the bug report.
        command_line: The entire command-line executed.
        error_message: The error message generated.
        log_file: Log file path of the subject's recon-all process.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BugrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BUGR_METADATA)
    cargs = []
    cargs.append("bugr")
    cargs.extend([
        "-subject",
        subject_name
    ])
    cargs.extend([
        "-command",
        command_line
    ])
    cargs.extend([
        "-error",
        error_message
    ])
    if log_file is not None:
        cargs.extend([
            "-log",
            execution.input_file(log_file)
        ])
    ret = BugrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BUGR_METADATA",
    "BugrOutputs",
    "bugr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SAMSEGMESH2SURF_METADATA = Metadata(
    id="d985be1373714eb0aff1a308730598604fe9d68c.boutiques",
    name="samsegmesh2surf",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Samsegmesh2surfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `samsegmesh2surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_file: OutputPathType | None
    """FreeSurfer surface file generated from SAMSEG atlas mesh"""
    output_priors_file: OutputPathType | None
    """Priors MRI volume at each vertex"""


def samsegmesh2surf(
    atlas_mesh: InputPathType,
    template: InputPathType | None = None,
    lta_transform: InputPathType | None = None,
    output_surface: str | None = None,
    output_priors: str | None = None,
    invert_flag: bool = False,
    runner: Runner | None = None,
) -> Samsegmesh2surfOutputs:
    """
    Generate Freesurfer surface from a SAMSEG atlas mesh file and generate priors at
    each vertex as overlay MRI volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        atlas_mesh: Input SAMSEG atlas mesh collection file.
        template: Input atlas template volume.
        lta_transform: Input LTA transform to be applied to surface.
        output_surface: Output FreeSurfer surface file.
        output_priors: Output priors as MRI volume.
        invert_flag: Invert LTA transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Samsegmesh2surfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SAMSEGMESH2SURF_METADATA)
    cargs = []
    cargs.append("samsegmesh2surf")
    cargs.extend([
        "--atlasmesh",
        execution.input_file(atlas_mesh)
    ])
    if template is not None:
        cargs.extend([
            "--template",
            "(" + execution.input_file(template)
        ])
    cargs.append("|")
    if lta_transform is not None:
        cargs.extend([
            "--lta",
            execution.input_file(lta_transform) + ")"
        ])
    if output_surface is not None:
        cargs.extend([
            "--osurf",
            "(" + output_surface
        ])
    cargs.append("|")
    if output_priors is not None:
        cargs.extend([
            "--opriors",
            output_priors + ")"
        ])
    if invert_flag:
        cargs.append("--invert")
    ret = Samsegmesh2surfOutputs(
        root=execution.output_file("."),
        output_surface_file=execution.output_file(output_surface) if (output_surface is not None) else None,
        output_priors_file=execution.output_file(output_priors) if (output_priors is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SAMSEGMESH2SURF_METADATA",
    "Samsegmesh2surfOutputs",
    "samsegmesh2surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_EDIT_SEGMENTATION_METADATA = Metadata(
    id="25345594af6f00c5d1125c06b5d3a088c2d5244f.boutiques",
    name="mri_edit_segmentation",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriEditSegmentationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_edit_segmentation(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_segmentation_file: OutputPathType
    """The resulting edited segmentation file."""


def mri_edit_segmentation(
    input_segmentation: InputPathType,
    t1_volume: InputPathType,
    output_segmentation: str,
    runner: Runner | None = None,
) -> MriEditSegmentationOutputs:
    """
    A tool used for editing segmentations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_segmentation: Input segmentation file.
        t1_volume: T1 volume file.
        output_segmentation: Output segmentation file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriEditSegmentationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_EDIT_SEGMENTATION_METADATA)
    cargs = []
    cargs.append("mri_edit_segmentation")
    cargs.append(execution.input_file(input_segmentation))
    cargs.append(execution.input_file(t1_volume))
    cargs.append(output_segmentation)
    ret = MriEditSegmentationOutputs(
        root=execution.output_file("."),
        output_segmentation_file=execution.output_file(output_segmentation),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_EDIT_SEGMENTATION_METADATA",
    "MriEditSegmentationOutputs",
    "mri_edit_segmentation",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STANDARD_SPACE_ROI_METADATA = Metadata(
    id="cc061c48c2d12a1afe15a890d8f2cfe7638fd047.boutiques",
    name="standard_space_roi",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class StandardSpaceRoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `standard_space_roi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_image: OutputPathType
    """Output image after masking and/or FOV reduction"""


def standard_space_roi(
    infile: InputPathType,
    outfile: str,
    mask_fov_flag: bool = False,
    mask_mask: InputPathType | None = None,
    mask_none_flag: bool = False,
    roi_fov_flag: bool = False,
    roi_mask: InputPathType | None = None,
    roi_none_flag: bool = False,
    ss_ref: InputPathType | None = None,
    alt_input: InputPathType | None = None,
    debug_flag: bool = False,
    bet_premask_flag: bool = False,
    runner: Runner | None = None,
) -> StandardSpaceRoiOutputs:
    """
    Masks input and/or reduces its FOV based on a standard space image or mask,
    transformed into the space of the input image.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        infile: Input image.
        outfile: Output image.
        mask_fov_flag: Mask output using transformed standard space FOV.
        mask_mask: Mask output using transformed standard space mask.
        mask_none_flag: Do not mask output.
        roi_fov_flag: Cut down input FOV using bounding box of the transformed\
            standard space FOV.
        roi_mask: Cut down input FOV using nonbackground bounding box of the\
            transformed standard space mask.
        roi_none_flag: Do not cut down input FOV.
        ss_ref: Standard space reference image to use (default:\
            /usr/local/fsl/data/standard/MNI152_T1).
        alt_input: Alternative input image to apply the ROI to (instead of the\
            one used to register to the reference).
        debug_flag: Debug mode (don't delete intermediate files).
        bet_premask_flag: Equivalent to: -maskMASK\
            /usr/local/fsl/data/standard/MNI152_T1_2mm_brain_mask_dil -roiNONE.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `StandardSpaceRoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(STANDARD_SPACE_ROI_METADATA)
    cargs = []
    cargs.append("standard_space_roi")
    cargs.append(execution.input_file(infile))
    cargs.append(outfile)
    if mask_fov_flag:
        cargs.append("-maskFOV")
    if mask_mask is not None:
        cargs.extend([
            "-maskMASK",
            execution.input_file(mask_mask)
        ])
    if mask_none_flag:
        cargs.append("-maskNONE")
    if roi_fov_flag:
        cargs.append("-roiFOV")
    if roi_mask is not None:
        cargs.extend([
            "-roiMASK",
            execution.input_file(roi_mask)
        ])
    if roi_none_flag:
        cargs.append("-roiNONE")
    if ss_ref is not None:
        cargs.extend([
            "-ssref",
            execution.input_file(ss_ref)
        ])
    if alt_input is not None:
        cargs.extend([
            "-altinput",
            execution.input_file(alt_input)
        ])
    if debug_flag:
        cargs.append("-d")
    if bet_premask_flag:
        cargs.append("-b")
    ret = StandardSpaceRoiOutputs(
        root=execution.output_file("."),
        out_image=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STANDARD_SPACE_ROI_METADATA",
    "StandardSpaceRoiOutputs",
    "standard_space_roi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIXEL2VOXEL_METADATA = Metadata(
    id="5fccec41beac5ebb945c548f352825b1de7de1ba.boutiques",
    name="fixel2voxel",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Fixel2voxelConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Fixel2voxelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fixel2voxel(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    image_out: OutputPathType
    """the output scalar image."""


def fixel2voxel(
    fixel_in: InputPathType,
    operation: str,
    image_out: str,
    number: int | None = None,
    fill: float | None = None,
    weighted: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Fixel2voxelConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Fixel2voxelOutputs:
    """
    Convert a fixel-based sparse-data image into some form of scalar image.
    
    Fixel data can be reduced to voxel data in a number of ways:
    
    - Some statistic computed across all fixel values within a voxel: mean, sum,
    product, min, max, absmax, magmax
    
    - The number of fixels in each voxel: count
    
    - Some measure of crossing-fibre organisation: complexity, sf
    ('single-fibre')
    
    - A 4D directionally-encoded colour image: dec_unit, dec_scaled
    
    - A 4D image containing all fixel data values in each voxel unmodified: none
    
    The -weighted option deals with the case where there is some per-fixel
    metric of interest that you wish to collapse into a single scalar measure
    per voxel, but each fixel possesses a different volume, and you wish for
    those fixels with greater volume to have a greater influence on the
    calculation than fixels with lesser volume. For instance, when estimating a
    voxel-based measure of mean axon diameter from per-fixel mean axon
    diameters, a fixel's mean axon diameter should be weigthed by its relative
    volume within the voxel in the calculation of that voxel mean.
    
    References:
    
    * Reference for 'complexity' operation:
    Riffert, T. W.; Schreiber, J.; Anwander, A. & Knosche, T. R. Beyond
    Fractional Anisotropy: Extraction of bundle-specific structural metrics from
    crossing fibre models. NeuroImage, 2014, 100, 176-191.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        fixel_in: the input fixel data file.
        operation: the operation to apply, one of: mean, sum, product, min,\
            max, absmax, magmax, count, complexity, sf, dec_unit, dec_scaled, none.
        image_out: the output scalar image.
        number: use only the largest N fixels in calculation of the voxel-wise\
            statistic; in the case of operation "none", output only the largest N\
            fixels in each voxel.
        fill: for "none" operation, specify the value to fill when number of\
            fixels is fewer than the maximum (default: 0.0).
        weighted: weight the contribution of each fixel to the per-voxel result\
            according to its volume.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fixel2voxelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIXEL2VOXEL_METADATA)
    cargs = []
    cargs.append("fixel2voxel")
    if number is not None:
        cargs.extend([
            "-number",
            str(number)
        ])
    if fill is not None:
        cargs.extend([
            "-fill",
            str(fill)
        ])
    if weighted is not None:
        cargs.extend([
            "-weighted",
            execution.input_file(weighted)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(fixel_in))
    cargs.append(operation)
    cargs.append(image_out)
    ret = Fixel2voxelOutputs(
        root=execution.output_file("."),
        image_out=execution.output_file(image_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIXEL2VOXEL_METADATA",
    "Fixel2voxelConfig",
    "Fixel2voxelOutputs",
    "fixel2voxel",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MMPPSP_METADATA = Metadata(
    id="f81f47b918a5f8423b269d5eccc58eb98d9d2e6f.boutiques",
    name="mmppsp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MmppspOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mmppsp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType
    """Output surface files"""


def mmppsp(
    samseg_dir: str,
    outdir: str,
    lh_flag: bool = False,
    rh_flag: bool = False,
    likelihood_flag: bool = False,
    posterior_flag: bool = False,
    force_update_flag: bool = False,
    threads: float | None = None,
    no_initsphreg_flag: bool = False,
    stop_after: str | None = None,
    wexpanddist: float | None = None,
    runner: Runner | None = None,
) -> MmppspOutputs:
    """
    MultiModal Posterior Probability Surface Placement.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        samseg_dir: Directory containing Samseg output.
        outdir: Output directory for the results.
        lh_flag: Process left hemisphere.
        rh_flag: Process right hemisphere.
        likelihood_flag: Use likelihood for surface placement.
        posterior_flag: Use posteriors instead of likelihood for surface\
            placement.
        force_update_flag: Force update the surface placement.
        threads: Number of threads to use.
        no_initsphreg_flag: Do not use talairach.lta to initialize rotation.
        stop_after: Stop the processing after a specified step.
        wexpanddist: Distance to expand white surface to initialize pial (in\
            mm).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MmppspOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MMPPSP_METADATA)
    cargs = []
    cargs.append("mmppsp")
    cargs.extend([
        "--samseg",
        samseg_dir
    ])
    cargs.extend([
        "--o",
        outdir
    ])
    if lh_flag:
        cargs.append("--lh")
    if rh_flag:
        cargs.append("--rh")
    if likelihood_flag:
        cargs.append("--likelihood")
    if posterior_flag:
        cargs.append("--posterior")
    if force_update_flag:
        cargs.append("--force-update")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if no_initsphreg_flag:
        cargs.append("--no-initsphreg")
    if stop_after is not None:
        cargs.extend([
            "--stop-after",
            stop_after
        ])
    if wexpanddist is not None:
        cargs.extend([
            "--wexpanddist",
            str(wexpanddist)
        ])
    ret = MmppspOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file(outdir + "/surf"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MMPPSP_METADATA",
    "MmppspOutputs",
    "mmppsp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_WARP_METADATA = Metadata(
    id="a60346ae5a51f63c7f32e60f45dc20db2e519c51.boutiques",
    name="mris_warp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisWarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_warp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType | None
    """Output surface file"""


def mris_warp(
    deformvol: str | None = None,
    m3z: str | None = None,
    regfile: str | None = None,
    surf: str | None = None,
    out: str | None = None,
    abs_: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrisWarpOutputs:
    """
    This program will warp a surface using a specified deformation field.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        deformvol: Volume containing deformation.
        m3z: M3Z file containing deformation.
        regfile: register.dat file between surface and volume.
        surf: Surface file to warp.
        out: Name for output surface (if does not contain '/', outputs to same\
            directory as input surface).
        abs_: Absolute coordinate displacement convention (default).
        help_: Print out information on how to use this program.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisWarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_WARP_METADATA)
    cargs = []
    cargs.append("mris_warp")
    if deformvol is not None:
        cargs.extend([
            "--deformvol",
            deformvol
        ])
    if m3z is not None:
        cargs.extend([
            "--m3z",
            m3z
        ])
    if regfile is not None:
        cargs.extend([
            "--reg",
            regfile
        ])
    if surf is not None:
        cargs.extend([
            "--surf",
            surf
        ])
    if out is not None:
        cargs.extend([
            "--out",
            out
        ])
    if abs_:
        cargs.append("--abs")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MrisWarpOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file(out) if (out is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_WARP_METADATA",
    "MrisWarpOutputs",
    "mris_warp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CREATE_TILED_MOSAIC_METADATA = Metadata(
    id="62ba9b499dd56904d0e9344bc41632c426e55fc9.boutiques",
    name="CreateTiledMosaic",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class CreateTiledMosaicOutputs(typing.NamedTuple):
    """
    Output object returned when calling `create_tiled_mosaic(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tiled_mosaic_image: OutputPathType
    """The output is the tiled mosaic image."""


def create_tiled_mosaic(
    input_image: InputPathType,
    output: InputPathType,
    rgb_image: InputPathType | None = None,
    mask_image: InputPathType | None = None,
    alpha: float | None = None,
    functional_overlay: str | None = None,
    tile_geometry: str | None = None,
    direction: typing.Literal["0", "1", "2", "x", "y", "z"] | None = None,
    pad_or_crop: str | None = None,
    slices: str | None = None,
    flip_slice: str | None = None,
    permute_axes: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> CreateTiledMosaicOutputs:
    """
    Render a 3-D image volume with optional Rgb overlay.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: Main input is a 3-D grayscale image.
        output: The output is the tiled mosaic image. The format must support\
            the specific data type: floating point images without RGB overlays, Rgb\
            images with intensities scaled to [0,255] if overlays are present.
        rgb_image: An optional Rgb image can be added as an overlay. It must\
            have the same image geometry as the input grayscale image.
        mask_image: Specifies the ROI of the RGB voxels used.
        alpha: If an Rgb image is provided, render the overlay using the\
            specified alpha parameter.
        functional_overlay: A functional overlay can be specified using both\
            and rgb image and a mask specifying where that rgb image should be\
            applied. Both images must have the same image geometry as the input\
            image. Optionally, an alpha parameter can be specified.
        tile_geometry: The tile geometry specifies the number of rows and\
            columns in the output image. For example, specifying '5x10' renders 5\
            rows by 10 columns of slices.
        direction: Specifies the direction of the slices. Can be based on image\
            storage in memory or aligned physical space. Defaults to z-direction if\
            unspecified.
        pad_or_crop: Specify padding or cropping with a voxel-width boundary\
            for each slice. Padding uses a specified constant value. Cropping pads\
            with negative voxel-widths.
        slices: Control over which slices to render. Specify slices directly or\
            incrementally with optional start and end slices.
        flip_slice: Flip individual slice images horizontally and/or\
            vertically.
        permute_axes: Permute (or swap) the axes of the individual slice\
            images.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CreateTiledMosaicOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CREATE_TILED_MOSAIC_METADATA)
    cargs = []
    cargs.append("CreateTiledMosaic")
    cargs.extend([
        "-i",
        execution.input_file(input_image)
    ])
    if rgb_image is not None:
        cargs.extend([
            "-r",
            execution.input_file(rgb_image)
        ])
    if mask_image is not None:
        cargs.extend([
            "-x",
            execution.input_file(mask_image)
        ])
    if alpha is not None:
        cargs.extend([
            "-a",
            str(alpha)
        ])
    if functional_overlay is not None:
        cargs.extend([
            "-e",
            functional_overlay
        ])
    cargs.extend([
        "-o",
        execution.input_file(output)
    ])
    if tile_geometry is not None:
        cargs.extend([
            "-t",
            tile_geometry
        ])
    if direction is not None:
        cargs.extend([
            "-d",
            direction
        ])
    if pad_or_crop is not None:
        cargs.extend([
            "-p",
            pad_or_crop
        ])
    if slices is not None:
        cargs.extend([
            "-s",
            slices
        ])
    if flip_slice is not None:
        cargs.extend([
            "-f",
            flip_slice
        ])
    if permute_axes is not None:
        cargs.extend([
            "-g",
            str(permute_axes)
        ])
    ret = CreateTiledMosaicOutputs(
        root=execution.output_file("."),
        tiled_mosaic_image=execution.output_file(pathlib.Path(output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CREATE_TILED_MOSAIC_METADATA",
    "CreateTiledMosaicOutputs",
    "create_tiled_mosaic",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VIENA_QUANT_METADATA = Metadata(
    id="51ebcfad9ed201b8538ee2a9ad0b420654d85cea.boutiques",
    name="viena_quant",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class VienaQuantOutputs(typing.NamedTuple):
    """
    Output object returned when calling `viena_quant(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_quantification: OutputPathType
    """Output quantification result"""


def viena_quant(
    input1: InputPathType,
    input2: InputPathType,
    ventricle_mask: InputPathType,
    runner: Runner | None = None,
) -> VienaQuantOutputs:
    """
    Automated brain ventricle quantification tool.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input1: Input image 1 (e.g. img1.nii.gz).
        input2: Input image 2 (e.g. img2.nii.gz).
        ventricle_mask: Ventricle mask (e.g. mask.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VienaQuantOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VIENA_QUANT_METADATA)
    cargs = []
    cargs.append("viena_quant")
    cargs.append(execution.input_file(input1))
    cargs.append(execution.input_file(input2))
    cargs.append(execution.input_file(ventricle_mask))
    ret = VienaQuantOutputs(
        root=execution.output_file("."),
        output_quantification=execution.output_file("output_quantification.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VIENA_QUANT_METADATA",
    "VienaQuantOutputs",
    "viena_quant",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_THICKNESS_DIFF_METADATA = Metadata(
    id="b447d6439b11ea7d939b51502ae54f028c61e756.boutiques",
    name="mris_thickness_diff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisThicknessDiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_thickness_diff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_difference: OutputPathType
    """Output file with the difference mapped onto the surface"""
    output_resampled: OutputPathType | None
    """Resampled output thickness file"""


def mris_thickness_diff(
    out_file: InputPathType,
    src_type: str | None = None,
    trg_type: str | None = None,
    out_resampled: InputPathType | None = None,
    nsmooth: float | None = None,
    register: bool = False,
    xform: InputPathType | None = None,
    invert: bool = False,
    src_volume: InputPathType | None = None,
    dst_volume: InputPathType | None = None,
    abs_: bool = False,
    log_file: InputPathType | None = None,
    subject_name: str | None = None,
    runner: Runner | None = None,
) -> MrisThicknessDiffOutputs:
    """
    Computes the difference of two surface data sets defined on two surface meshes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        out_file: Output file name.
        src_type: Input surface data format (curv, paint or w).
        trg_type: Output format (paint or w).
        out_resampled: Output resampled thickness.
        nsmooth: Number of smoothing steps.
        register: Perform ICP rigid registration.
        xform: Apply LTA transform to align input surface1 to surface2.
        invert: Reversely apply -xform.
        src_volume: Source volume for -xform.
        dst_volume: Target volume for -xform.
        abs_: Compute the std of abs-thickness-diff.
        log_file: Log file name.
        subject_name: Subject name (to be recorded in logfile).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisThicknessDiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_THICKNESS_DIFF_METADATA)
    cargs = []
    cargs.append("mris_thickness_diff")
    cargs.append("[SURFACE1]")
    cargs.append("[DATA1]")
    cargs.append("[SURFACE2]")
    cargs.append("[DATA2]")
    if src_type is not None:
        cargs.extend([
            "-src_type",
            src_type
        ])
    if trg_type is not None:
        cargs.extend([
            "-trg_type",
            trg_type
        ])
    cargs.extend([
        "-out",
        execution.input_file(out_file)
    ])
    if out_resampled is not None:
        cargs.extend([
            "-out_resampled",
            execution.input_file(out_resampled)
        ])
    if nsmooth is not None:
        cargs.extend([
            "-nsmooth",
            str(nsmooth)
        ])
    if register:
        cargs.append("-register")
    if xform is not None:
        cargs.extend([
            "-xform",
            execution.input_file(xform)
        ])
    if invert:
        cargs.append("-invert")
    if src_volume is not None:
        cargs.extend([
            "-src",
            execution.input_file(src_volume)
        ])
    if dst_volume is not None:
        cargs.extend([
            "-dst",
            execution.input_file(dst_volume)
        ])
    if abs_:
        cargs.append("-abs")
    if log_file is not None:
        cargs.extend([
            "-L",
            execution.input_file(log_file)
        ])
    if subject_name is not None:
        cargs.extend([
            "-S",
            subject_name
        ])
    ret = MrisThicknessDiffOutputs(
        root=execution.output_file("."),
        output_difference=execution.output_file(pathlib.Path(out_file).name),
        output_resampled=execution.output_file(pathlib.Path(out_resampled).name) if (out_resampled is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_THICKNESS_DIFF_METADATA",
    "MrisThicknessDiffOutputs",
    "mris_thickness_diff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_MONKEY_METADATA = Metadata(
    id="4dccc2f58e68c24781760f51b33e78d977f7eaa8.boutiques",
    name="segment_monkey",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentMonkeyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_monkey(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def segment_monkey(
    control_points: list[str],
    runner: Runner | None = None,
) -> SegmentMonkeyOutputs:
    """
    A tool for segmenting images using specified control points.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        control_points: List of control points required for segmentation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentMonkeyOutputs`).
    """
    if not (1 <= len(control_points)): 
        raise ValueError(f"Length of 'control_points' must be greater than 1 but was {len(control_points)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_MONKEY_METADATA)
    cargs = []
    cargs.append("segment_monkey")
    cargs.extend(control_points)
    ret = SegmentMonkeyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_MONKEY_METADATA",
    "SegmentMonkeyOutputs",
    "segment_monkey",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NICAT_METADATA = Metadata(
    id="150f64c79ef2ef5b2c3f9c0b00bdeb1447c981cd.boutiques",
    name="nicat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class NicatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `nicat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def nicat(
    stream_spec: str,
    reopen: str | None = None,
    copy_stream: bool = False,
    read_only: bool = False,
    runner: Runner | None = None,
) -> NicatOutputs:
    """
    Copies stdin to the NIML stream, which will be opened for writing.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        stream_spec: Stream specification (e.g., tcp:localhost:4444).
        reopen: Reopen the stream after connection to the stream specified by\
            the given value.
        copy_stream: Copy the stream to stdout instead; the 'streamspec' will\
            be opened for reading.
        read_only: Read the stream but don't copy to stdout.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NicatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NICAT_METADATA)
    cargs = []
    cargs.append("nicat")
    cargs.append(stream_spec)
    if reopen is not None:
        cargs.extend([
            "-reopen",
            reopen
        ])
    if copy_stream:
        cargs.append("-r")
    if read_only:
        cargs.append("-R")
    ret = NicatOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NICAT_METADATA",
    "NicatOutputs",
    "nicat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_HEMI_MASK_METADATA = Metadata(
    id="55920b5b609569d7bec1e1ab50384958b7621427.boutiques",
    name="make_hemi_mask",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeHemiMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_hemi_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Hemisphere masked MRI volume output"""


def make_hemi_mask(
    hemi: str,
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> MakeHemiMaskOutputs:
    """
    Generates a hemisphere mask by registering input to the left/right reversed
    version using mri_robust_register, then keeps only the selected hemisphere.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemi: Hemisphere to keep ('lh' for left hemisphere, 'rh' for right\
            hemisphere).
        input_file: Input MRI volume file (e.g. input.mgz).
        output_file: Output masked MRI volume file (e.g. output.mgz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeHemiMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_HEMI_MASK_METADATA)
    cargs = []
    cargs.append("make_hemi_mask")
    cargs.append(hemi)
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = MakeHemiMaskOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_HEMI_MASK_METADATA",
    "MakeHemiMaskOutputs",
    "make_hemi_mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPHERE_SUBJECT_RH_METADATA = Metadata(
    id="844b29d70c1496f2da433daa0b47df80e286dc3b.boutiques",
    name="sphere_subject-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SphereSubjectRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sphere_subject_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def sphere_subject_rh(
    license_file: InputPathType,
    runner: Runner | None = None,
) -> SphereSubjectRhOutputs:
    """
    Sphere Subject RH tool for FreeSurfer, requires valid license.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        license_file: Path to FreeSurfer license file, can be specified with\
            the FS_LICENSE environmental variable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SphereSubjectRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPHERE_SUBJECT_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "sphere_subject" + execution.input_file(license_file)
    ])
    ret = SphereSubjectRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPHERE_SUBJECT_RH_METADATA",
    "SphereSubjectRhOutputs",
    "sphere_subject_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CHECK_RECONS_SH_METADATA = Metadata(
    id="52142d2a907acd3a0d9631fc56bcb011b2c8e9af.boutiques",
    name="check_recons.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class CheckReconsShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `check_recons_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def check_recons_sh(
    subject_directory: str | None = None,
    runner: Runner | None = None,
) -> CheckReconsShOutputs:
    """
    Checks the status of subjects being processed by recon-all in the SUBJECTS_DIR
    or a specified directory.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_directory: Directory where subjects are being processed. If not\
            specified, uses SUBJECTS_DIR.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CheckReconsShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CHECK_RECONS_SH_METADATA)
    cargs = []
    cargs.append("check_recons.sh")
    if subject_directory is not None:
        cargs.append(subject_directory)
    ret = CheckReconsShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CHECK_RECONS_SH_METADATA",
    "CheckReconsShOutputs",
    "check_recons_sh",
]
